searchData={"items":[{"type":"module","title":"Solo","doc":"`Solo` is the library to turn parts of the existing supervision trees into singletons.\n\nConsider the application having the following children specified somewhere in the supervision tree.\n\n```elixir\nchildren = [\n  Foo,\n  {Bar, [bar_arg]},\n  {Baz, [baz_arg]},\n  ...\n]\n```\n\nand there is a necessity to make `Bar` and `Baz` processes singletons across the cluster.\nSimply wrap the specs in question into `Solo.global/2` and you are all set.\n\n```elixir\nchildren = [\n  Foo,\n  Solo.global(SoloBarBaz, [\n    {Bar, [bar_arg]},\n    {Baz, [baz_arg]}\n  ],\n  ...\n]\n```","ref":"Solo.html"},{"type":"function","title":"Solo.global/3","doc":"Helper to make parts of the supervision tree a global distributed singleton.\n\nSimply wrap the parts of any supervision tree with a call to `Solo.global/2`\nand you ar eall set.\n\n```elixir\nchildren = [\n  Foo,\n  Solo.global(SoloBarBaz, [\n    {Bar, [bar_arg]},\n    {Baz, [baz_arg]}\n  ],\n  ...\n]\n```\n\nThe name (`SoloBarBaz`) above might be used later to check the state of the\nrunning `Solo` supervisor with `Solo.state/1`, although this is usually not\na demanded feature.\n\nTo lookup the named processes turned into `Solo`, use `Solo.whereis/1`,\npassing the respective id (`SoloBarBaz`) and the actual name of the process.","ref":"Solo.html#global/3"},{"type":"function","title":"Solo.state/1","doc":"Returns the state of the `Solo` from this node’s perspective (pids of workers\nmight be remote.)","ref":"Solo.html#state/1"},{"type":"function","title":"Solo.whereis/1","doc":"Looks the process with the name given as the first parameter up.","ref":"Solo.html#whereis/1"},{"type":"extras","title":"Solo","doc":"# Solo    [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/am-kantox/solo/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/am-kantox/solo/workflows/Dialyzer/badge.svg)","ref":"readme.html"},{"type":"extras","title":"Objective - Solo","doc":"This library might be handy when one needs to keep a singleton across the cluster with zero downtime.\nConsider the application needs to collect some data from the external source when the only one \nconnection is allowed. If for some reason the node running a connection goes down, the takeover\nfrom other node should have happened. In the old good days we used native _erlang_ \n[failover/takeover](https://www.erlang.org/doc/system/distributed_applications.html#failover)\nmechanism for that, but nowadays in the cloud any container might go down unexpectedly due to\nsome internal considerations of _ECS_.\n\nIn such a case the application would need to immediately restart the connection on one of the\nnodes still alive. This library transparently makes it possible to turn any number of processes\nin the supervision tree into such singletons without writing much code.\n\nSimply wrap the specs into `Solo.global/2` call and you are all set.\n\n```elixir\nchildren = [\n  Foo,\n  Solo.global(SoloBarBaz, [\n    {Bar, [bar_arg]},\n    {Baz, [baz_arg]}\n  ],\n  ...\n]\n```","ref":"readme.html#objective"},{"type":"extras","title":"Implementation - Solo","doc":"The library uses both [`Process.monitor/1`](https://hexdocs.pm/elixir/Process.html#monitor/1)\nand [`:pg.monitor/1`](https://www.erlang.org/doc/apps/kernel/pg.html#monitor/1) to get\nacknowledged about disappeared processes. Each node carries the state of the monitored cluster\nto restart processes on some of the still alive nodes when necessary.\n\n`Solo` is backed by `Supervisor`, unlike e. g. [`Singleton`](https://github.com/arjan/singleton),\nwhich uses `DynamicSupervisor`, allowing for next to zero boilerplate\nand resurrection from brutal VM crashes.","ref":"readme.html#implementation"},{"type":"extras","title":"Installation - Solo","doc":"The package can be installed by adding `solo` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:solo, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"FAQ - Solo","doc":"- **Is it of any good?** — Sure it is.\n- **Would it work for me?** — Well, it works on my machine.\n\n## [Documentation](https://hexdocs.pm/solo)","ref":"readme.html#faq"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}